/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 1999-2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
** dlg_file_save_as.c
**
** This file implements the "file save as" dialog for the scheduler project.
**
** $Log: dlg_file_save_as.c,v $
** Revision 1.3  2000/02/26 05:22:26  bstpierre
** Finished task12064: Clean up interface between UI and back end.
**
** Revision 1.2  2000/02/25 02:41:32  bstpierre
** * Changed task to C structure from C++ class; simplified interface somewhat;
**   changed task.hpp to task.h.
** * Changed scheduler.cpp to scheduler.c (get rid of useless C++).
** * Changed task_tree interface to accept a task object, rather than just
**   the description string.
**
** Revision 1.1.1.1  2000/02/10 04:33:20  bstpierre
** Initial sourceforge cvs upload, corresponds to release 0.0.8.
**
** Revision 1.2  2000/02/01 19:59:09  brian
** Added CopyLeft notice to file header
**
** Revision 1.1  2000/01/31 22:47:00  brian
** Initial revision
**
**/

#include <assert.h>

#include <gnome.h>
#include <gtk/gtk.h>

#include "scheduler.h"
#include "command.h"
#include "task.h"
#include "dialogs.h"

void dlg_file_save_as(char* filenameOut, size_t maxFilenameOutLen)
{
    GtkWidget * dialog;
    GtkWidget* fileentry; 
    int reply;
   
    dialog = gnome_dialog_new(_("Scheduler: Save As"), 
                              GNOME_STOCK_BUTTON_OK,
                              GNOME_STOCK_BUTTON_CANCEL,
                              NULL);

    gnome_dialog_set_close(GNOME_DIALOG(dialog), TRUE);
    gnome_dialog_close_hides(GNOME_DIALOG(dialog), TRUE);

    fileentry = gnome_file_entry_new("scheduler:scheduler_loadsave_history",
                                     _("Scheduler: Browse Files For Save As"));

    gnome_dialog_editable_enters(GNOME_DIALOG(dialog), 
        GTK_EDITABLE(gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(fileentry))));
    gnome_dialog_set_default(GNOME_DIALOG(dialog), GNOME_OK);

    gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox),
                       fileentry,
                       TRUE, TRUE, GNOME_PAD);
   

    gtk_widget_show_all(dialog);

    reply = gnome_dialog_run(GNOME_DIALOG(dialog));
   
    if (reply == GNOME_OK)
    {      
        gchar* filename;

        filename = gnome_file_entry_get_full_path(GNOME_FILE_ENTRY(fileentry),
                                                  FALSE);

        /* Copy the name to the output variable. */
        assert(strlen(filename) < maxFilenameOutLen);
        strcpy(filenameOut, filename);

        cmd_project_save(filename);
    }
   
    gtk_widget_destroy(dialog);  
}

