/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 1999-2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
** dlg_project_new.c
**
** This implements the "new project" dialog box.  The external interface
** for this dialog is declared in dialogs.h.
**
** $Log: dlg_project_new.c,v $
** Revision 1.3  2000/02/25 05:13:05  bstpierre
** * Changed Project from class to struct; project.cpp to project.c
** * Changed task_tree_set_project to take Project object instead of description
** * Fixed bugs in Task object introduced by last checkin.
** * Added Debug menu that is conditionally compiled (-DDEBUG to use).
** * Fixed up a couple of command APIs
**
** Revision 1.2  2000/02/25 02:41:32  bstpierre
** * Changed task to C structure from C++ class; simplified interface somewhat;
**   changed task.hpp to task.h.
** * Changed scheduler.cpp to scheduler.c (get rid of useless C++).
** * Changed task_tree interface to accept a task object, rather than just
**   the description string.
**
** Revision 1.1.1.1  2000/02/10 04:33:20  bstpierre
** Initial sourceforge cvs upload, corresponds to release 0.0.8.
**
** Revision 1.5  2000/02/01 19:59:09  brian
** Added CopyLeft notice to file header
**
** Revision 1.4  2000/01/06 22:33:45  brian
** - Changed to use higher level GNOME functions; simplified.
**
**/

#include <gnome.h>
#include <gtk/gtk.h>

#include "scheduler.h"
#include "command.h"
#include "task.h"
#include "dialogs.h"

static void
dlg_project_new_callback(gchar* projDesc, gpointer data)
{
    if(projDesc != NULL)
    {
        cmd_project_new(projDesc);
        g_free(projDesc);
    }
}

void
dlg_project_new(GnomeApp* app)
{
    gnome_request_dialog(FALSE, "Enter project description", NULL, 256,
                         dlg_project_new_callback, NULL, GTK_WINDOW(app));
}
