/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 1999-2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
** menu.c
**
** This file defines the data for the menu.  g_menubar is the only
** global variable.  Also defined here are the callbacks used by the
** menus.
**
** $Id: menu.c,v 1.8 2000/03/27 03:35:38 bstpierre Exp $
*/

#include <gnome.h>
#include "scheduler.h"
#include "menu.h"
#include "control.h"
#include "dialogs.h"
#include "command.h"
#include "task_tree.h"
#include "status_bar.h"

static char curFilename[NAME_MAX] = "";

static void callback_file_open()
{
    dlg_file_open(curFilename, sizeof(curFilename));
}

static void callback_file_save()
{
    /* If we have not yet chosen a file, invoke the 'save as' dialog.
     * Otherwise just save to the already chosen file. */
    if(strlen(curFilename) == 0)
    {
        dlg_file_save_as(curFilename, sizeof(curFilename));
    }
    else
    {
        cmd_project_save(curFilename);
    }
}

static void callback_file_save_as()
{
    dlg_file_save_as(curFilename, sizeof(curFilename));
}

static void
callback_project_new()
{
    dlg_project_new(GNOME_APP(g_app));
}

static void
callback_task_add()
{
    dlg_task_add(GNOME_APP(g_app));
}

static void callback_task_edit()
{
    Task* task;

    task = task_tree_get_current_task();
    if(task == NULL)
    {
        status_bar_set_message(_("Select a task first."));
    }
    else
    {
        dlg_task_edit(GNOME_APP(g_app), task);
    }
}

static void callback_task_remove()
{
    Task* task;

    task = task_tree_get_current_task();
    if(task == NULL)
    {
        status_bar_set_message(_("Select a task first."));
    }
    else
    {
        cmd_task_remove(task);
    }
}

static void
callback_report_tasks()
{
    cmd_report_run("task");
}

#ifdef DEBUG
static void
callback_debug_project_dump()
{
    cmd_project_dump();
}

static void
callback_debug_status_bar()
{
    status_bar_set_message("This is a test message");
}

#endif /* DEBUG */

static GnomeUIInfo file_menu[] =
{
    GNOMEUIINFO_MENU_OPEN_ITEM(callback_file_open,NULL),
    GNOMEUIINFO_MENU_SAVE_ITEM(callback_file_save,NULL),
    GNOMEUIINFO_MENU_SAVE_AS_ITEM(callback_file_save_as,NULL),
    GNOMEUIINFO_MENU_EXIT_ITEM(gtk_main_quit,NULL),
    GNOMEUIINFO_END
};

static GnomeUIInfo project_menu[] =
{
    GNOMEUIINFO_ITEM_NONE("_New Project",
                          "Create a new project",
                          callback_project_new),
    GNOMEUIINFO_END
};

static GnomeUIInfo task_menu[] =
{
    GNOMEUIINFO_ITEM_NONE("_Add Task",
                          "Create a new task",
                          callback_task_add),
    GNOMEUIINFO_ITEM_NONE("_Edit Task",
                          "Edit the selected task",
                          callback_task_edit),
    GNOMEUIINFO_ITEM_NONE("_Remove Task",
                          "Remove the selected task",
                          callback_task_remove),
    GNOMEUIINFO_END
};

static GnomeUIInfo report_menu[] =
{
    GNOMEUIINFO_ITEM_NONE("_Task Report",
                          "List the tasks in the active project",
                          callback_report_tasks),
    GNOMEUIINFO_END
};

#ifdef DEBUG
static GnomeUIInfo debug_menu[] =
{
    GNOMEUIINFO_ITEM_NONE("_Project Dump",
                          "Dump the active project",
                          callback_debug_project_dump),
    GNOMEUIINFO_ITEM_NONE("_Status Bar Test",
                          "Shows a message in the status bar",
                          callback_debug_status_bar),
    GNOMEUIINFO_END
};
#endif /* DEBUG */

GnomeUIInfo g_menubar[] =
{
    GNOMEUIINFO_MENU_FILE_TREE(file_menu),
    GNOMEUIINFO_SUBTREE("_Project", project_menu),
    GNOMEUIINFO_SUBTREE("_Task", task_menu),
    GNOMEUIINFO_SUBTREE("_Report", report_menu),
#ifdef DEBUG
    GNOMEUIINFO_SUBTREE("_Debug", debug_menu),
#endif /* DEBUG */
    GNOMEUIINFO_END
};
