/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 1999-2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* project.h
**
** This file implements the Project class.  This collects tasks and
** provides other related services.
**
** $Id: project.h,v 1.5 2000/03/27 03:38:24 bstpierre Exp $
*/

#ifndef __PROJECT_H__
#define __PROJECT_H__

#include <glib.h>
#include "task.h"

struct Project_t
{
    TaskId nextTaskId;
    GString* description;
    GList* tasks;
};

typedef struct Project_t Project;

#ifdef __cplusplus
extern "C" {
#endif

/* This initializes a project object. */
Project* project_new(gchar* description);

/* This releases memory/resources associated with a project object. */
void project_free(Project* project);

/*  This adds a task to the given project.  Duplicates are allowed. */
void project_add_task(Project* project, Task* task);

/* This returns a pointer to the task with the given task id, or NULL
** if the task id was not found. */
Task* project_find_task_by_id(const Project* project, TaskId tid);

/* This provides an GList of all of the tasks in this project.
** This is intended for use by the report generators.  If you need
** to search for a given task, use project_find_task_by_id().
*/
GList* project_get_tasks(const Project* project);

/* This removes a task with the given id from a project.  If duplicates
** exist, only the first one found is removed.  If preserveDepyChain
** is true, any tasks which has a dependency on the task being removed
** will be made dependent on the dependencies of the task being removed.
** ie. t1 depends on t2, and t2 depends on t3; t2 is removed with 
** preserveDepyChain=true; t1 is made dependent on t3. */
void project_remove_task(Project* project,
                         TaskId tid,
                         gboolean preserveDepyChain);

#ifdef DEBUG
/* This dumps a project object to the console.
** Useful for debugging. */
void project_dump(const Project* project);
#endif /* DEBUG */

#ifdef __cplusplus
}
#endif

#endif // __PROJECT_H__
