/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 1999-2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

// reportmgr.hpp
//
// This file implements the report manager class and each of the available
// reports.
//

#include <stdio.h> // For sprintf().

#include "reportmgr.hpp"

static void TaskReport(Project* project);

// Initialize the instance variable to NULL so that we know whether
// we've created our single instance yet.
ReportMgr* ReportMgr::_instance = NULL;

ReportMgr::ReportMgr()
{
    // Currently the only available report.
    _reports["task"] = TaskReport;
}

ReportMgr&
ReportMgr::GetReportMgr()
{
    if(_instance == NULL)
    {
        _instance = new ReportMgr();
        if(_instance == NULL)
        {
            cerr << "ERROR: out of memory\n";
            throw;
        }
    }

    return (*_instance);
}

bool
ReportMgr::RunReport(string reportName, Project* project)
{
    ReportFunc func;

    // Look up the report by name.
    func = _reports[reportName];
    if(func != NULL)
    {
        // Run the report.
        func(project);
        return true;
    }
    else
    {
        // Report not found.
        return false;
    }
}

void TaskReport(Project* project)
{
    GList* taskList;
    GList* iter;
    char outBuf[81];
    char completedStr[12];

    // Output the header.
    taskList = project_get_tasks(project);
    iter = g_list_first(taskList);

    sprintf(outBuf, "\n%s,%s,%s,%s\n",
            "Id", "Description", "Estimate", "Actual");
    cout << outBuf;

    // Output the body of the report, one line per task.
    while(iter != NULL)
    {
        Task* task;
        memset(outBuf, 0, sizeof(outBuf));

        task = (Task*)iter->data;
        if(task->isComplete)
        {
            sprintf(completedStr, "%ld", (task->actualTime / 24 / 60 / 60));
        }
        else
        {
            sprintf(completedStr, "%s", "incomplete");
        }

        sprintf(outBuf, "%d,%s,%ld,%s\n",
                task->id, task->description->str,
                (task->estimatedTime / 24 / 60 / 60), completedStr);
        cout << outBuf;

        iter = g_list_next(iter);
    }
}
