/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 1999-2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

// reportmgr.hpp
//
// This file implements the report manager class.  This is a collection
// of named reports.  Each report is implemented as a single function in 
// the implementation file.
//
// This is implemented as a singleton.
//

#ifndef __REPORTMGR_HPP__
#define __REPORTMGR_HPP__

#include <string>
#include <map>
#include "project.h"

class ReportMgr
{
public:
    // This returns the single instance of ReportMgr.
    static ReportMgr& GetReportMgr();

    // This runs the report 'reportName'.
    // RETURNS: true if 'reportName' exists, false if not found.
    bool RunReport(string reportName, Project* project);

private:
    // Hide the constructor.
    ReportMgr();

    static ReportMgr* _instance;

    // This stores the mapping of name --> ReportFunc.
    typedef void (*ReportFunc)(Project*);
    map<string, ReportFunc> _reports;
};

#endif // __REPORTMGR_HPP__


