/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 1999-2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* scheduler.cpp
**
** This file contains the main entry point into the scheduler application.
** This application provides the user with a simple project task scheduler.
**
** $Log: scheduler.c,v $
** Revision 1.2  2000/02/26 03:23:58  bstpierre
** Finished task11582: "Add a status bar"
** Finished task11573: "Put full task information into the task tree"
**
** Revision 1.1  2000/02/25 02:41:32  bstpierre
** * Changed task to C structure from C++ class; simplified interface somewhat;
**   changed task.hpp to task.h.
** * Changed scheduler.cpp to scheduler.c (get rid of useless C++).
** * Changed task_tree interface to accept a task object, rather than just
**   the description string.
**
** Revision 1.2  2000/02/21 00:33:09  bstpierre
** Changed task_tree from C++ to C
**
** Revision 1.1.1.1  2000/02/10 04:33:21  bstpierre
** Initial sourceforge cvs upload, corresponds to release 0.0.8.
**
** Revision 1.5  2000/02/01 19:59:09  brian
** Added CopyLeft notice to file header
**
** Revision 1.4  2000/01/06 22:34:29  brian
** - Set global variable to share GnomeApp object.
**
** Revision 1.3  2000/01/06 00:17:46  brian
** - Added initialization of task_tree in main app window.
**
** Revision 1.2  2000/01/04 23:24:29  brian
** - Added Log keyword.
** - Removed include of commandinterpreter.hpp (dropped from project).
**
*/

#include <gnome.h>

#include "scheduler.h"
#include "menu.h"
#include "status_bar.h"
#include "task_tree.h"

char g_appName[] = "scheduler";
GtkWidget* g_app = NULL;

int main(int argc, char** argv)
{
    /* Initialize GNOME. */
    gnome_init ("Scheduler", "0.1", argc, argv);

    /* Create the main app window, including menus. */
    g_app = gnome_app_new ("Scheduler",
                         "General Purpose Project Scheduler");
    gtk_signal_connect (GTK_OBJECT (g_app), "delete_event",
                        GTK_SIGNAL_FUNC (gtk_main_quit),
                        NULL);
    gnome_app_create_menus (GNOME_APP(g_app), g_menubar);

    /* Create the status bar. */
    status_bar_init(GNOME_APP(g_app));

    /* Create a tree of tasks inside the main window. */
    task_tree_init(GNOME_APP(g_app));
    gtk_widget_show_all(g_app);

    /* Enter tha main app message loop. */
    gtk_main();

    return 0;
}
