/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* status_bar.c
**
** This file handles the status bar widget for the main application window.
**
*/

#include <gnome.h>
#include "scheduler.h"
#include "status_bar.h"
#include "task.h"

static GtkWidget* g_statusBar = NULL;

void status_bar_init(GnomeApp* app)
{
    g_assert(g_statusBar == NULL);
    g_assert(app != NULL);

    g_statusBar = gnome_appbar_new(FALSE, TRUE, GNOME_PREFERENCES_USER);
    gnome_app_set_statusbar(GNOME_APP(app), g_statusBar);
}

void status_bar_set_message(gchar* message)
{
    g_assert(g_statusBar != NULL);
    g_assert(message != NULL);

    gnome_appbar_set_status(GNOME_APPBAR(g_statusBar), message);
}

void status_bar_set_task(const Task* task)
{
    gchar* message;

    g_assert(g_statusBar != NULL);
    g_assert(task != NULL);

    message = g_strdup_printf("%s: %d, %s",
                               task->description->str,
                               task->id,
                               task->isComplete ? "complete" : "incomplete");
    gnome_appbar_set_status(GNOME_APPBAR(g_statusBar), message);
    g_free(message);
}

void status_bar_set_project(const Project* project)
{
    /* FIXME: Need a real message. */
    gnome_appbar_set_status(GNOME_APPBAR(g_statusBar), "A project (FIXME)");
}
