/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
**
** task.c
**
** This task implements the internals of the "Task" encapsulation.
**/

#include "scheduler.h"
#include "task.h"

Task* task_new()
{
    Task* newTask;

    /* Allocate heap memory for this new task. */
    newTask = g_new(Task, 1);

    /* Initialize each of the members of the task. */

    /* TBD: Should this be a meaningful task id?  Maybe initialization
     * should occur in connection with a project, from which I could
     * get (and increment) the next task id? */
    newTask->id = 0;

    newTask->description = g_string_new("");
    newTask->estimatedTime = 0;
    newTask->actualTime = 0;
    newTask->startDate = 0;

    /* Intuitively, tasks are not completed when they are created. */
    newTask->isComplete = FALSE;

    /* A GList is initialized to the empty list by setting the pointer
     * to NULL. */
    newTask->dependencies = NULL;

    return newTask;
}

void task_free(Task* task)
{
    g_assert(task != NULL);

    g_string_free(task->description, TRUE);

    GSCHED_SHRED_OBJECT(task, Task);
    g_free(task);
}

void task_set_description(Task* task, gchar* description)
{
    g_assert(task != NULL);
    g_assert(description != NULL);

    g_string_assign(task->description, description);
}
