/*  gscheduler - A General Purpose Project Scheduler
**  Copyright (C) 1999-2000  Brian St. Pierre
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* task.h
**
** This file encapsulates a "task".
*/

#ifndef __TASK_H__
#define __TASK_H__

typedef int TaskId;

#include <glib.h>
#include <time.h>

/* A task is a bit of work to be performed in the context of the project
** that is under the management of this application.  (E.g. a task
** might be "inspect i/o class code", expected to take 1 hour,
** not yet completed.)
*/
struct Task_t
{
    TaskId id;
    GString* description;
    time_t estimatedTime;
    time_t actualTime;
    time_t startDate;
    gboolean isComplete;
    GList* dependencies;
};

typedef struct Task_t Task;

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Creates a new task.
 */
Task* task_new();

/*
 * Releases a task and associated memory/resources.
 */
void task_free(Task*);

/*
 *  Sets a new description for a task.
 */
void task_set_description(Task* task, gchar* description);

#ifdef __cplusplus
}
#endif

#endif // __TASK_H__
